@@ -61,7 +61,11 @@ elif dpkg-architecture -iany-ppc64el || dpkg-architecture -iany-ppc64; then
 elif dpkg-architecture -iany-s390x; then
 	OPT=jit
 fi
-RPYOPTS="$RPYOPTS --opt=$OPT --no-shared"
+RPYOPTS="$RPYOPTS --opt=$OPT --shared"
+
+if [ $OPT = 3 ]; then
+	RPYOPTS="$RPYOPTS --no-profopt"
+fi
 
 if [ $OPT = "mem" -o $OPT = "jit" -o $OPT = 2 -o $OPT = 3 ]; then
 	RPYOPTS="$RPYOPTS --gcrootfinder=$ROOTFINDER"
@@ -93,6 +97,8 @@ if echo "$PYTHON" | grep -Fq pypy; then
 	fi
 fi
 
+RPYTHON="$(pwd)/rpython/bin/rpython"
+
 set -x
 cd pypy/goal
-exec $PYTHON -u ../../rpython/bin/rpython $RPYOPTS targetpypystandalone $TARGETOPTS 2>&1
+exec $PYTHON -u $RPYTHON $RPYOPTS targetpypystandalone $TARGETOPTS 2>&1
